@@ -2,39 +2,19 @@
 Geometryutils - a Python library for processing mesh and point cloud data.
 """
 
-#trimesh
-#PyMesh
-#pygalmesh => builds upon eigen and cgal
-#Plyable
-
-#IMPORT PACKAGES
-# import trimesh
-
-# from ast import Try
-# from lib2to3.pytree import Node
-# from turtle import shape
 from xmlrpc.client import Boolean
 import numpy as np 
-# import cv2 
 import open3d as o3d 
 import copy
-
-# import matplotlib.pyplot as plt #conda install -c conda-forge matplotlib
-#import torch #conda install -c pytorch pytorch
-import pye57 #conda install xerces-c  =>  pip install pye57
+import pye57 
 import xml.etree.ElementTree as ET 
 import math
-# from datetime import datetime
 from typing import List
-# from rdflib import Graph
 
 import ifcopenshell
 import ifcopenshell.geom as geom
 import ifcopenshell.util
-# from ifcopenshell.util.selector import Selector
-# import multiprocessing
 from scipy.spatial.transform import Rotation as R
-import trimesh
 
 #IMPORT MODULES watch out for circular imports
 import geomapi
@@ -286,7 +266,7 @@ def pointcloud_filter_by_distance(source: o3d.geometry.PointCloud, cutters, thre
         outputmesh(o3d.geometry.PointCloud)
     """
     #if no list, list
-    cutters=item_to_list(cutters)
+    cutters=ut.item_to_list(cutters)
     joined=join_geometries(cutters)
 
     #if cutters are mesh, sample mesh
@@ -305,46 +285,6 @@ def pointcloud_filter_by_distance(source: o3d.geometry.PointCloud, cutters, thre
     else:
         return None 
 
-def cap_mesh(test):
-    """UNTESTED CODE
-    """
-      # the plane we're using
-    normal = trimesh.unitize([1,1,1])
-    origin = m.center_mass
-
-    # get a section as a Path3D object
-    s = m.section(plane_origin=origin,
-                  plane_normal=normal)
-
-    # transform the Path3D onto the XY plane so we can triangulate
-    on_plane, to_3D = s.to_planar()
-
-    # triangulate each closed region of the 2D cap
-    v, f = [], []
-    for polygon in on_plane.polygons_full:
-        tri = trimesh.creation.triangulate_polygon(polygon)
-        v.append(tri[0])
-        f.append(tri[1])
-        
-    # append the regions and re- index
-    vf, ff = trimesh.util.append_faces(v, f)
-    # three dimensionalize polygon vertices
-    vf = np.column_stack((vf, np.zeros(len(vf))))
-    # transform points back to original mesh frame
-    vf = trimesh.transform_points(vf, to_3D)
-    # flip winding of faces for cap
-    ff = np.fliplr(ff)
-
-    # the mesh for the planar cap
-    cap = trimesh.Trimesh(vf, ff)
-
-    # get the uncapped slice
-    sliced = m.slice_plane(plane_origin=origin,
-                           plane_normal=normal)
-
-    # append the cap to the sliced mesh
-    capped = sliced + cap
-
 def box_to_mesh(box:o3d.geometry) ->o3d.geometry.TriangleMesh:
     if type(box) is o3d.geometry.OrientedBoundingBox or type(box) is o3d.geometry.AxisAlignedBoundingBox:
         mesh=o3d.geometry.TriangleMesh()
@@ -434,40 +374,6 @@ def get_box_intersections(sourceBox:o3d.geometry.OrientedBoundingBox, testBoxes:
     list = [ i for i in range(len(array)) if array[i]]
     return list
 
-def mesh_to_trimesh(geometry: o3d.geometry) -> trimesh.Trimesh:
-    """
-    Convert open3D.geometry.TriangleMesh to trimesh.Trimesh
-    """
-    if type(geometry) is o3d.geometry.OrientedBoundingBox or type(geometry) is o3d.geometry.AxisAlignedBoundingBox:
-        geometry=box_to_mesh(geometry)
-    
-    if type(geometry) is o3d.geometry.TriangleMesh and len(geometry.vertices) !=0:
-        vertices= geometry.vertices
-        faces= geometry.triangles
-        face_normals=None
-        vertex_normals=None
-        face_colors=None
-        vertex_colors=None
-
-        if geometry.has_triangle_normals():
-            face_normals=geometry.triangle_normals
-        if geometry.has_vertex_normals():
-            vertex_normals=geometry.vertex_normals
-        if geometry.has_triangle_uvs(): # this is probably not correct
-            face_colors=geometry.triangle_uvs
-        if geometry.has_vertex_colors():
-            vertex_colors=geometry.vertex_colors
-
-        try:
-            triMesh= trimesh.Trimesh(vertices, faces, face_normals=face_normals, vertex_normals=vertex_normals, face_colors=face_colors, vertex_colors=vertex_colors)
-            return triMesh
-        except:
-            print('Open3D to Trimesh failed')
-            return None
-    else:
-        print('Incorrect geometry input. Only input o3d.geometry.TriangleMesh,o3d.geometry.AxisAlignedBoundingBox or o3d.geometry.OrientedBoundingBox or type(geometry)  ')
-        return None
-
 
 def rotation_and_translation_to_transformation_matrix(rotation: np.array, translation: np.array)->np.array:
     """
@@ -513,7 +419,11 @@ def ifc_to_mesh(ifcElement:ifcopenshell.entity_instance)-> o3d.geometry.Triangle
             o3dTriangles = o3d.utility.Vector3iVector(np.asarray(faces))
 
             # Create the Open3D mesh object
-            return o3d.geometry.TriangleMesh(o3dVertices,o3dTriangles) 
+            mesh=o3d.geometry.TriangleMesh(o3dVertices,o3dTriangles)
+            if len(mesh.triangles)>1:
+                return mesh
+            else: 
+                return None 
     except:
         print('ifcopenshell.entity_instance error')
         return None
@@ -726,29 +636,6 @@ def mesh_collisions_open3d(sourceMesh: o3d.geometry.TriangleMesh, meshes: List[o
                 # smoothMesh=mesh.subdivide_midpoint(1)
         return False
 
-def mesh_collisions_trimesh(sourceMesh: trimesh.Trimesh, meshes: List[trimesh.Trimesh], t_d:float=0.5) -> List[int]:
-
-    if type(sourceMesh) is o3d.geometry.TriangleMesh and len(sourceMesh.triangles) !=0:
-        myTrimesh=mesh_to_trimesh(sourceMesh)
-
-        # add all geometries to the collision manager
-        collisionManager=trimesh.collision.CollisionManager()
-        # trimeshes=np.empty(len(meshes),dtype=trimesh.Trimesh)
-        for idx,mesh in enumerate(meshes):
-            if type(mesh) is o3d.geometry.TriangleMesh and len(mesh.triangles) >1:
-                referenceTrimesh=mesh_to_trimesh(mesh)
-                collisionManager.add_object(idx,referenceTrimesh)
-
-        # report the collisions with the sourceMesh
-        (is_collision, names ) = collisionManager.in_collision_single(myTrimesh, transform=None, return_names=False, return_data=False)    
-        if is_collision:
-            list=[int(name) for name in names]
-            return list
-        # collisionManager.add_object(0,myTrimesh)
-        # collisionManager.add_object(1,referenceTrimesh)
-       
-    return None
-
 def mesh_intersection_raycasting(source:o3d.geometry.TriangleMesh, cutter: o3d.geometry.TriangleMesh, inside : Boolean = True,strict : Boolean = True ) -> o3d.geometry.TriangleMesh:
     """"Select portion of a mesh that lies within a mesh shape (if not closed, convexhull is called)
     
@@ -817,39 +704,6 @@ def mesh_to_pcd(mesh:o3d.geometry.TriangleMesh,voxelSize : float = 0.1) -> o3d.g
     pcd = pcd.voxel_down_sample(voxelSize)    
     return pcd
 
-def mesh_intersection_convex_hull(source:trimesh.Trimesh, cutter: trimesh.Trimesh, inside : Boolean = True ) -> trimesh.Trimesh:
-    """"Cut a portion of a mesh that lies within/outside the convex hull of another mesh
-    
-    Args:
-        source (trimesh.Trimesh):   mesh that will be cut
-        cutter (trimesh.Trimesh):   mesh of which the faces are used for the cuts. Face normals should point outwards (positive side)
-        inside (Boolean):           True if retain the inside of the intersection
-    Returns:
-        mesh:       trimesh.Trimesh 
-        None:       if no data was retained
-    """
-    #compute faces and centers
-    convexhull=cutter.convex_hull
-    plane_normals=convexhull.face_normals
-    plane_origins=convexhull.triangles_center
-
-    if inside: # retain inside
-        return(source.slice_plane(plane_origins, -1*plane_normals))
-    else:# retain outside
-        #cut source mesh for every slicing plane on the box
-        meshes=[]
-        for n, o in zip(plane_normals, plane_origins):
-            tempMesh= source.slice_plane(o, n)
-            if not tempMesh.is_empty:
-                meshes.append(tempMesh)
-        if len(meshes) !=0: # gather pieces
-            combined = trimesh.util.concatenate( [ meshes ] )
-            combined.merge_vertices(merge_tex =True,merge_norm =True )
-            combined.remove_duplicate_faces()
-            return combined
-        else:
-            return None
-
 def oriented_bounds_to_open3d_oriented_bounding_box(orientedBounds : np.array) -> o3d.geometry.OrientedBoundingBox:
     """Convert 8 bounding points to Open3D Geometry
 
