@@ -155,11 +155,17 @@ class PointCloudNode (geomapi.geometrynode.GeometryNode):
         if getattr(self,'pcd',None) is not None:
             self.pcd=None
 
-    def get_pcd(self):
-        if getattr(self,'pcd',None) is not None:
+    def get_pcd(self) -> o3d.geometry.PointCloud:
+        """Returns the pointcloud data in the node. If none is present, it will search for the data on drive.
+
+        Returns:
+            o3d.geometry.PointCloud or None
+        """
+        if getattr(self,'pcd',None) is not None and len(self.pcd.points)>3:
             return self.pcd 
-        else:
-            return None  
+        elif self.get_geometry():
+            return self.pcd
+        return None  
 
     def get_metadata_from_pcd(self) ->bool:
         """Gets the PointCount, cartesianTransform, cartesianBounds and orientedBounds from an o3d.geometry.PointCloud
@@ -198,10 +204,14 @@ class PointCloudNode (geomapi.geometrynode.GeometryNode):
                     self.pcd=pcd
                     return True
             if  getattr(self,'e57Index',None) is not None:                    
-                if getattr(self,'e57XmlPath',None) is not None:
-                    e57Path=self.e57XmlPath.replace('.xml','.e57')
+                if getattr(self,'e57XmlPath',None) is not None:                    
+                    e57Path=self.e57XmlPath.replace('.xml','.e57')                    
                     if os.path.exists(e57Path):
                         self.e57Path=e57Path
+                        pcd=gt.e57_to_pcd(self.e57Path, self.e57Index)
+                        if len(pcd.points) != 0:
+                            self.pcd=pcd
+                        return True
 
                 if getattr(self,'e57Path',None) is not None and os.path.exists(self.e57Path):            
                     pcd=gt.e57_to_pcd(self.e57Path, self.e57Index)
@@ -213,18 +223,21 @@ class PointCloudNode (geomapi.geometrynode.GeometryNode):
                     allSessionFilePaths=ut.get_list_of_files(self.path)
                     testE57Path= self.sessionPath +'\\'+ self.name + '.e57'
                     testPcdPath= self.sessionPath + '\\'+ self.name + '.pcd'
-                    if testE57Path in allSessionFilePaths:
-                        self.e57Path=testE57Path
-                        pcd=gt.e57_to_pcd(self.e57Path, self.e57Index)
-                        if len(pcd.points) != 0:
-                            self.pcd=pcd
-                            return True
-                    elif testPcdPath in allSessionFilePaths:
+                    if testPcdPath in allSessionFilePaths:
                         pcd = o3d.io.read_point_cloud(testPcdPath)
                         if len(pcd.points) != 0:
                             self.path=testPcdPath
                             self.pcd=pcd
                             return True
+                    elif testE57Path in allSessionFilePaths:
+                        self.e57Path=testE57Path
+                        pcd=gt.e57_to_pcd(self.e57Path, self.e57Index)
+                        if len(pcd.points) != 0:
+                            self.pcd=pcd
+                            return True
+        elif getattr(self,'pc',None) is not None:
+            if len(self.pc.points)>3:
+                return True            
         return False
     
     def get_metadata_from_e57(self) -> bool:
@@ -236,6 +249,7 @@ class PointCloudNode (geomapi.geometrynode.GeometryNode):
         e57 = pye57.E57(self.e57Path)   
         header = e57.get_header(self.e57Index)
         try:
+            self.name=ut.get_filename(self.e57Path) +'_'+str(self.e57Index)
             self.pointCount=header.point_count
             self.guid=header["guid"].value()
             r=header.rotation_matrix
